@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -20,16 +20,9 @@
 #ifndef _OSIP_MT_H_
 #define _OSIP_MT_H_
 
-#ifdef OSIP_MT
-
-#ifdef ENABLE_MPATROL
-#include <mpatrol.h>
-#endif
+#ifndef OSIP_MONOTHREAD
 
 #include <stdio.h>
-#ifndef _WIN32_WCE
-#include <errno.h>
-#endif
 
 /**
  * @file osip_mt.h
@@ -46,8 +39,7 @@
  */
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 /**
@@ -62,8 +54,7 @@ extern "C"
  * @param func The method where the thread start.
  * @param arg A pointer on the argument given to the method 'func'.
  */
-  struct osip_thread *osip_thread_create (int stacksize,
-                                          void *(*func) (void *), void *arg);
+  struct osip_thread *osip_thread_create (int stacksize, void *(*func) (void *), void *arg);
 
 /**
  * Join a thread.
@@ -85,18 +76,13 @@ extern "C"
 #ifdef __cplusplus
 }
 #endif
-
-/** @} */
-
-/**
+/** @}
  * @defgroup oSIP_SEMA oSIP semaphore definitions
  * @ingroup osip2_port
  * @{
  */
-
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 /**
@@ -137,18 +123,13 @@ extern "C"
 #ifdef __cplusplus
 }
 #endif
-
-/** @} */
-
-/**
+/** @}
  * @defgroup oSIP_MUTEX oSIP mutex definitions
  * @ingroup osip2_port
  * @{
  */
-
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 /**
@@ -180,9 +161,6 @@ extern "C"
 #ifdef __cplusplus
 }
 #endif
-
 /** @} */
-
-#endif                          /* OSIP_MT */
-
+#endif                          /* OSIP_MONOTHREAD */
 #endif                          /* end of _THREAD_H_ */
