@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -21,19 +21,18 @@
 #define _OSIP_TIME_H_
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 /* Common time-related functions and data types */
 
 #if defined(_WIN32_WCE)
-struct _timeb {
-  time_t time;
-  unsigned short millitm;
-  short timezone;
-  short dstflag;
-};
+  struct _timeb {
+    time_t time;
+    unsigned short millitm;
+    short timezone;
+    short dstflag;
+  };
 
 #endif
 
@@ -48,32 +47,25 @@ struct _timeb {
 #if defined(WIN32) || defined(_WIN32_WCE) || defined (__VXWORKS_OS__) || defined(__arc__)
 /* Operations on struct timeval */
 #define osip_timerisset(tvp)         ((tvp)->tv_sec || (tvp)->tv_usec)
-# define osip_timercmp(a, b, CMP)                          \
+#define osip_timercmp(a, b, CMP)                          \
   (((a)->tv_sec == (b)->tv_sec) ?                          \
    ((a)->tv_usec CMP (b)->tv_usec) :                       \
    ((a)->tv_sec CMP (b)->tv_sec))
 #define osip_timerclear(tvp)         (tvp)->tv_sec = (tvp)->tv_usec = 0
 
-/* osip_gettimeofday() for Windows */
-#if defined(__arc__)
-#define osip_gettimeofday gettimeofday
-#else
-  int osip_gettimeofday (struct timeval *tp, void *tz);
-#endif
-
 #else
 /* Operations on struct timeval */
 #define osip_timerisset(tvp)            timerisset(tvp)
 #define osip_timercmp(tvp, uvp, cmp)    timercmp(tvp,uvp,cmp)
 #define osip_timerclear(tvp)            timerclear(tvp)
 
-/* osip_gettimeofday() == gettimeofday() */
-#define osip_gettimeofday gettimeofday
-
 #endif
 
+  int osip_gettimeofday (struct timeval *tp, void *tz);
+  time_t osip_getsystemtime (time_t * t);
+  void osip_compensatetime (void);
+
 #ifdef __cplusplus
 }
 #endif
-
 #endif
