@@ -1,6 +1,6 @@
 /*
-  The oSIP library implements the Session Initiation Protocol (SIP -rfc2543-)
-  Copyright (C) 2001  Aymeric MOIZARD jack@atosc.org
+  The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -34,14 +34,18 @@
 
 /**
  * Structure for Call-Id headers.
- * @defvar osip_call_id_t
+ * @var osip_call_id_t
  */
   typedef struct osip_call_id osip_call_id_t;
 
+/**
+ * Definition of the Call-Id header.
+ * @struct osip_call_id
+ */
   struct osip_call_id
   {
-    char *number;
-    char *host;
+    char *number;    /**< Call-ID number */
+    char *host;      /**< Call-ID host information */
   };
 
 #ifdef __cplusplus
