@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -29,11 +29,7 @@
  * @file osip_list.h
  * @brief oSIP list Routines
  *
- * This is a very simple implementation of a linked list.
- * <BR>There is not much to say about it... Except that it
- * could be a lot improved. Sadly, it would be difficult
- * to improve it without breaking the compatibility with
- * older version!
+ * This is a simple implementation of a linked list.
  */
 
 /**
@@ -42,8 +38,7 @@
  */
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 #ifndef DOXYGEN
@@ -57,10 +52,9 @@ extern "C"
  * Structure for referencing a node in a osip_list_t element.
  * @struct __node
  */
-  struct __node
-  {
-    void *next;                 /**< next __node_t containing element */
-    void *element;              /**< element in Current node */
+  struct __node {
+    __node_t *next;         /**< next __node_t containing element */
+    void *element;          /**< element in Current node */
   };
 #endif
 
@@ -74,23 +68,21 @@ extern "C"
  * Structure used to iterate list.
  * @var osip_list_iterator_t
  */
-  typedef struct
-  {
-    __node_t *actual;
-    __node_t **prev;
-    osip_list_t *li;
-    int pos;
+  typedef struct {
+    __node_t *actual; /**< actual */
+    __node_t **prev;  /**< prev */
+    osip_list_t *li;  /**< li */
+    int pos;          /**< pos */
   } osip_list_iterator_t;
 
 /**
  * Structure for referencing a list of elements.
  * @struct osip_list
  */
-  struct osip_list
-  {
+  struct osip_list {
 
-    int nb_elt;         /**< Number of element in the list */
-    __node_t *node;     /**< Next node containing element  */
+    int nb_elt;                 /**< Number of element in the list */
+    __node_t *node;             /**< Next node containing element  */
 
   };
 
@@ -110,7 +102,7 @@ extern "C"
  * @param li The element to work on.
  * @param free_func The method that is able to release one element of the list.
  */
-  void osip_list_special_free (osip_list_t * li, void *(*free_func) (void *));
+  void osip_list_special_free (osip_list_t * li, void (*free_func) (void *));
 /**
  * Clone a list of element.
  * Each element will be cloned with the method given as the second parameter.
@@ -164,8 +156,8 @@ extern "C"
  * Get first iterator from list.
  * @param li The element to work on.
  * @param it The iterator.
- */ 
-void *osip_list_get_first (osip_list_t * li, osip_list_iterator_t * it);
+ */
+  void *osip_list_get_first (osip_list_t * li, osip_list_iterator_t * it);
 /**
  * GEt next iterator.
  * @param it The element to work on.
@@ -180,8 +172,5 @@ void *osip_list_get_first (osip_list_t * li, osip_list_iterator_t * it);
 #ifdef __cplusplus
 }
 #endif
-
-
 /** @} */
-
 #endif
