@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -42,8 +42,7 @@
  */
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 /**
@@ -56,10 +55,9 @@ extern "C"
  * SDP bandwidth definition.
  * @struct sdp_bandwidth
  */
-  struct sdp_bandwidth
-  {
-    char *b_bwtype;             /**< bandwidth type */
-    char *b_bandwidth;          /**< bandwidth value */
+  struct sdp_bandwidth {
+    char *b_bwtype;                             /**< bandwidth type */
+    char *b_bandwidth;                          /**< bandwidth value */
   };
 
 /**
@@ -83,11 +81,10 @@ extern "C"
  * SDP Time description definition.
  * @struct sdp_time_descr
  */
-  struct sdp_time_descr
-  {
-    char *t_start_time;            /**< start time */
-    char *t_stop_time;             /**< stop time */
-    osip_list_t r_repeats;        /**< repeat headers */
+  struct sdp_time_descr {
+    char *t_start_time;                            /**< start time */
+    char *t_stop_time;                             /**< stop time */
+    osip_list_t r_repeats;                /**< repeat headers */
   };
 
 /**
@@ -111,10 +108,9 @@ extern "C"
  * SDP key definition.
  * @struct sdp_key
  */
-  struct sdp_key
-  {
-    char *k_keytype;    /**< Key Type (prompt, clear, base64, uri) */
-    char *k_keydata;    /**< key data */
+  struct sdp_key {
+    char *k_keytype;            /**< Key Type (prompt, clear, base64, uri) */
+    char *k_keydata;            /**< key data */
   };
 
 /**
@@ -138,10 +134,9 @@ extern "C"
  * SDP attribute definition.
  * @struct sdp_attribute
  */
-  struct sdp_attribute
-  {
-    char *a_att_field;          /**< attribute field */
-    char *a_att_value;          /**< attribute value (optional) */
+  struct sdp_attribute {
+    char *a_att_field;                          /**< attribute field */
+    char *a_att_value;                          /**< attribute value (optional) */
   };
 
 /**
@@ -166,13 +161,14 @@ extern "C"
  * SDP connection definition.
  * @struct sdp_connection
  */
-  struct sdp_connection
-  {
-    char *c_nettype;             /**< Network Type */
-    char *c_addrtype;            /**< Network Address Type */
-    char *c_addr;                /**< Address */
-    char *c_addr_multicast_ttl;  /**< TTL value for multicast address */
-    char *c_addr_multicast_int;  /**< Number of multicast address */
+  struct sdp_connection {
+    char *c_nettype;                             /**< Network Type */
+    char *c_addrtype;                            /**< Network Address Type */
+    char *c_addr;                                /**< Address */
+    char *c_addr_multicast_ttl;
+                                                                 /**< TTL value for multicast address */
+    char *c_addr_multicast_int;
+                                                                 /**< Number of multicast address */
   };
 
 /**
@@ -196,19 +192,21 @@ extern "C"
  * SDP media definition.
  * @struct sdp_media
  */
-  struct sdp_media
-  {
-    char *m_media;              /**< media type */
-    char *m_port;               /**< port number */
-    char *m_number_of_port;     /**< number of port */
-    char *m_proto;              /**< protocol to be used */
-    osip_list_t m_payloads;    /**< list of payloads (as strings) */
+  struct sdp_media {
+    char *m_media;                              /**< media type */
+    char *m_port;                               /**< port number */
+    char *m_number_of_port;             /**< number of port */
+    char *m_proto;                              /**< protocol to be used */
+    osip_list_t m_payloads;            /**< list of payloads (as strings) */
 
-    char *i_info;               /**< information header */
-    osip_list_t c_connections; /**< list of sdp_connection_t * */
-    osip_list_t b_bandwidths;  /**< list of sdp_bandwidth_t * */
-    osip_list_t a_attributes;  /**< list of sdp_attribute_t * */
-    sdp_key_t *k_key;           /**< key informations */
+    char *i_info;                               /**< information header */
+    osip_list_t c_connections;
+                                                           /**< list of sdp_connection_t * */
+    osip_list_t b_bandwidths;
+                                                           /**< list of sdp_bandwidth_t * */
+    osip_list_t a_attributes;
+                                                           /**< list of sdp_attribute_t * */
+    sdp_key_t *k_key;                           /**< key informations */
   };
 
 /**
@@ -232,27 +230,29 @@ extern "C"
  * SDP message definition.
  * @struct sdp_message
  */
-  struct sdp_message
-  {
-    char *v_version;            /**< version header */
-    char *o_username;           /**< Username */
-    char *o_sess_id;            /**< Identifier for session */
-    char *o_sess_version;       /**< Version of session */
-    char *o_nettype;            /**< Network type */
-    char *o_addrtype;           /**< Address type */
-    char *o_addr;               /**< Address */
-    char *s_name;               /**< Subject header */
-    char *i_info;               /**< Information header */
-    char *u_uri;                /**< Uri header */
-    osip_list_t e_emails;      /**< list of mail address */
-    osip_list_t p_phones;      /**< list of phone numbers * */
-    sdp_connection_t *c_connection;   /**< Connection information */
-    osip_list_t b_bandwidths;  /**< list of bandwidth info (sdp_bandwidth_t) */
-    osip_list_t t_descrs;      /**< list of time description (sdp_time_descr_t) */
-    char *z_adjustments;        /**< Time adjustment header */
-    sdp_key_t *k_key;           /**< Key information header */
-    osip_list_t a_attributes;  /**< list of global attributes (sdp_attribute_t) */
-    osip_list_t m_medias;      /**< list of supported media (sdp_media_t) */
+  struct sdp_message {
+    char *v_version;                            /**< version header */
+    char *o_username;                           /**< Username */
+    char *o_sess_id;                            /**< Identifier for session */
+    char *o_sess_version;               /**< Version of session */
+    char *o_nettype;                            /**< Network type */
+    char *o_addrtype;                           /**< Address type */
+    char *o_addr;                               /**< Address */
+    char *s_name;                               /**< Subject header */
+    char *i_info;                               /**< Information header */
+    char *u_uri;                                /**< Uri header */
+    osip_list_t e_emails;              /**< list of mail address */
+    osip_list_t p_phones;              /**< list of phone numbers * */
+    sdp_connection_t *c_connection;
+                                                                          /**< Connection information */
+    osip_list_t b_bandwidths;
+                                                           /**< list of bandwidth info (sdp_bandwidth_t) */
+    osip_list_t t_descrs;              /**< list of time description (sdp_time_descr_t) */
+    char *z_adjustments;                /**< Time adjustment header */
+    sdp_key_t *k_key;                           /**< Key information header */
+    osip_list_t a_attributes;
+                                                           /**< list of global attributes (sdp_attribute_t) */
+    osip_list_t m_medias;              /**< list of supported media (sdp_media_t) */
   };
 
 
@@ -307,9 +307,7 @@ extern "C"
  * @param addrtype The token value.
  * @param addr The token value.
  */
-  int sdp_message_o_origin_set (sdp_message_t * sdp, char *username,
-                                char *sess_id, char *sess_version,
-                                char *nettype, char *addrtype, char *addr);
+  int sdp_message_o_origin_set (sdp_message_t * sdp, char *username, char *sess_id, char *sess_version, char *nettype, char *addrtype, char *addr);
 /**
  * Get the username ('o' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -414,14 +412,10 @@ extern "C"
  * @param addr_multicast_ttl The token value.
  * @param addr_multicast_int The token value.
  */
-  int sdp_message_c_connection_add (sdp_message_t * sdp, int pos_media,
-                                    char *nettype, char *addrtype,
-                                    char *addr, char *addr_multicast_ttl,
-                                    char *addr_multicast_int);
+  int sdp_message_c_connection_add (sdp_message_t * sdp, int pos_media, char *nettype, char *addrtype, char *addr, char *addr_multicast_ttl, char *addr_multicast_int);
 #ifndef DOXYGEN
 /* this method should be internal only... */
-  sdp_connection_t *sdp_message_connection_get (sdp_message_t * sdp,
-                                                int pos_media, int pos);
+  sdp_connection_t *sdp_message_connection_get (sdp_message_t * sdp, int pos_media, int pos);
 #endif
 /**
  * Get the network type ('c' field) of a SDP packet.
@@ -450,16 +444,14 @@ extern "C"
  * @param pos_media The media line number.
  * @param pos The index in the connection element list..
  */
-  char *sdp_message_c_addr_multicast_ttl_get (sdp_message_t * sdp,
-                                              int pos_media, int pos);
+  char *sdp_message_c_addr_multicast_ttl_get (sdp_message_t * sdp, int pos_media, int pos);
 /**
  * Get the multicast int info ('c' field) of a SDP packet.
  * @param sdp The element to work on.
  * @param pos_media The media line number.
  * @param pos The index in the connection element list..
  */
-  char *sdp_message_c_addr_multicast_int_get (sdp_message_t * sdp,
-                                              int pos_media, int pos);
+  char *sdp_message_c_addr_multicast_int_get (sdp_message_t * sdp, int pos_media, int pos);
 /**
  * Set the version in a SDP packet.
  * @param sdp The element to work on.
@@ -467,16 +459,14 @@ extern "C"
  * @param bwtype The token value.
  * @param bandwidth The token value.
  */
-  int sdp_message_b_bandwidth_add (sdp_message_t * sdp, int pos_media,
-                                   char *bwtype, char *bandwidth);
+  int sdp_message_b_bandwidth_add (sdp_message_t * sdp, int pos_media, char *bwtype, char *bandwidth);
 /**
  * Get the bandwidth ('b' field) of a SDP packet.
  * @param sdp The element to work on.
  * @param pos_media The media line number.
  * @param pos The index in the bandwidth element list..
  */
-  sdp_bandwidth_t *sdp_message_bandwidth_get (sdp_message_t * sdp,
-                                              int pos_media, int pos);
+  sdp_bandwidth_t *sdp_message_bandwidth_get (sdp_message_t * sdp, int pos_media, int pos);
 /**
  * Get the bandwidth type ('b' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -516,16 +506,14 @@ extern "C"
  * @param pos_time_descr index of t field.
  * @param value The token value.
  */
-  int sdp_message_r_repeat_add (sdp_message_t * sdp, int pos_time_descr,
-                                char *value);
+  int sdp_message_r_repeat_add (sdp_message_t * sdp, int pos_time_descr, char *value);
 /**
  * Get the repeat information ('r' field) in a SDP packet.
  * @param sdp The element to work on.
  * @param pos_time_descr index of t field.
  * @param pos_repeat index of element in the 'r' field.
  */
-  char *sdp_message_r_repeat_get (sdp_message_t * sdp, int pos_time_descr,
-                                  int pos_repeat);
+  char *sdp_message_r_repeat_get (sdp_message_t * sdp, int pos_time_descr, int pos_repeat);
 /**
  * Set the adjustments ('z' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -544,8 +532,7 @@ extern "C"
  * @param keytype The token value.
  * @param keydata The token value.
  */
-  int sdp_message_k_key_set (sdp_message_t * sdp, int pos_media,
-                             char *keytype, char *keydata);
+  int sdp_message_k_key_set (sdp_message_t * sdp, int pos_media, char *keytype, char *keydata);
 /**
  * Get the key type ('k' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -565,16 +552,14 @@ extern "C"
  * @param att_field The token value.
  * @param att_value The token value.
  */
-  int sdp_message_a_attribute_add (sdp_message_t * sdp, int pos_media,
-                                   char *att_field, char *att_value);
+  int sdp_message_a_attribute_add (sdp_message_t * sdp, int pos_media, char *att_field, char *att_value);
 /**
  * delete all attribute fields specified by att_field.
  * @param sdp The element to work on.
  * @param pos_media The line number.
  * @param att_field The value to remove.
  */
-  int sdp_message_a_attribute_del (sdp_message_t * sdp, int pos_media,
-                                   char *att_field);
+  int sdp_message_a_attribute_del (sdp_message_t * sdp, int pos_media, char *att_field);
 /**
  * delete one specific attribute fields specified by att_field.
  * @param sdp The element to work on.
@@ -582,17 +567,14 @@ extern "C"
  * @param att_field The value to remove.
  * @param pos_attr The index of attribute to remove.
  */
-  int sdp_message_a_attribute_del_at_index (sdp_message_t * sdp,
-                                            int pos_media, char *att_field,
-                                            int pos_attr);
+  int sdp_message_a_attribute_del_at_index (sdp_message_t * sdp, int pos_media, char *att_field, int pos_attr);
  /**
  * Get one of the attribute ('a' field) of a SDP packet.
  * @param sdp The element to work on.
  * @param pos_media The media line number.
  * @param pos The attribute line number.
  */
-  sdp_attribute_t *sdp_message_attribute_get (sdp_message_t * sdp,
-                                              int pos_media, int pos);
+  sdp_attribute_t *sdp_message_attribute_get (sdp_message_t * sdp, int pos_media, int pos);
 /**
  * Get the attribute name ('a' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -621,8 +603,7 @@ extern "C"
  * @param number_of_port The token value.
  * @param proto The token value.
  */
-  int sdp_message_m_media_add (sdp_message_t * sdp, char *media,
-                               char *port, char *number_of_port, char *proto);
+  int sdp_message_m_media_add (sdp_message_t * sdp, char *media, char *port, char *number_of_port, char *proto);
 /**
  * Get the media type ('m' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -660,8 +641,7 @@ extern "C"
  * @param pos_media The line number.
  * @param payload The token value.
  */
-  int sdp_message_m_payload_add (sdp_message_t * sdp, int pos_media,
-                                 char *payload);
+  int sdp_message_m_payload_add (sdp_message_t * sdp, int pos_media, char *payload);
 /**
  * Get one of the payload number ('m' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -684,6 +664,4 @@ extern "C"
 #ifdef __cplusplus
 }
 #endif
-
-
 #endif
