@@ -177,9 +177,12 @@ ixt_free (ixt_t * ixt)
 void
 osip_start_200ok_retransmissions (osip_t * osip, osip_dialog_t * dialog, osip_message_t * msg200ok, int sock)
 {
+  int i;
   ixt_t *ixt;
 
-  ixt_init (&ixt);
+  i = ixt_init (&ixt);
+  if (i != 0)
+    return;
   ixt->dialog = dialog;
   osip_message_clone (msg200ok, &ixt->msg2xx);
   ixt->sock = sock;
@@ -251,8 +254,8 @@ ixt_retransmit (osip_t * osip, ixt_t * ixt, struct timeval *current)
 {
   if (osip_timercmp (current, &ixt->start, >)) {
     ixt->interval = ixt->interval * 2;
-    if (ixt->interval > 4000)
-      ixt->interval = 4000;
+    if (ixt->interval > DEFAULT_T2)
+      ixt->interval = DEFAULT_T2;
     add_gettimeofday (&ixt->start, ixt->interval);
     if (ixt->ack != NULL)
       osip->cb_send_message (NULL, ixt->ack, ixt->dest, ixt->port, ixt->sock);
