@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -17,8 +17,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include <stdlib.h>
-#include <stdio.h>
+#include <osipparser2/internal.h>
 
 #include <osipparser2/osip_port.h>
 #include <osipparser2/osip_message.h>
@@ -28,28 +27,29 @@
 #ifndef MINISIZE
 
 int
-osip_content_disposition_parse(osip_content_disposition_t * cd, const char *hvalue)
+osip_content_disposition_parse (osip_content_disposition_t * cd, const char *hvalue)
 {
-	const char *cd_params;
-	int i;
+  const char *cd_params;
+  int i;
 
-	cd_params = strchr(hvalue, ';');
+  cd_params = strchr (hvalue, ';');
 
-	if (cd_params != NULL) {
-		i = __osip_generic_param_parseall(&cd->gen_params, cd_params);
-		if (i != 0)
-			return i;
-	} else
-		cd_params = hvalue + strlen(hvalue);
+  if (cd_params != NULL) {
+    i = __osip_generic_param_parseall (&cd->gen_params, cd_params);
+    if (i != 0)
+      return i;
+  }
+  else
+    cd_params = hvalue + strlen (hvalue);
 
-	if (cd_params - hvalue + 1 < 2)
-		return OSIP_SYNTAXERROR;
-	cd->element = (char *) osip_malloc(cd_params - hvalue + 1);
-	if (cd->element == NULL)
-		return OSIP_NOMEM;
-	osip_clrncpy(cd->element, hvalue, cd_params - hvalue);
+  if (cd_params - hvalue + 1 < 2)
+    return OSIP_SYNTAXERROR;
+  cd->element = (char *) osip_malloc (cd_params - hvalue + 1);
+  if (cd->element == NULL)
+    return OSIP_NOMEM;
+  osip_clrncpy (cd->element, hvalue, cd_params - hvalue);
 
-	return OSIP_SUCCESS;
+  return OSIP_SUCCESS;
 }
 
 #endif
