@@ -79,9 +79,21 @@
 #include <sys/time.h>
 #elif defined(WIN32)
 #include <windows.h>
+#if (_MSC_VER >= 1700) && !defined(_USING_V110_SDK71_)
+#if defined(WINAPI_FAMILY) && (WINAPI_FAMILY == WINAPI_FAMILY_PHONE_APP)
+#include <winsock2.h>
+#elif defined(WINAPI_FAMILY) && WINAPI_FAMILY_ONE_PARTITION( WINAPI_FAMILY, WINAPI_PARTITION_APP )
+#else
 #ifdef WIN32_USE_CRYPTO
 #include <Wincrypt.h>
 #endif
+#endif
+#else
+#ifdef WIN32_USE_CRYPTO
+#include <Wincrypt.h>
+#endif
+#endif
+
 #endif
 
 #if defined (__rtems__)
@@ -302,7 +314,6 @@ osip_build_random_number ()
     srand (ticks);
     random_seed_set = 1;
   }
-
   err = CryptAcquireContext (&crypto, NULL, NULL, PROV_RSA_FULL, CRYPT_VERIFYCONTEXT);
   if (err) {
     err = CryptGenRandom (crypto, sizeof (num), (BYTE *) & num);
@@ -367,24 +378,13 @@ osip_atoi (const char *number)
 
 #endif
 
-/* append string_osip_to_append to string at position cur
-   size is the current allocated size of the element
-*/
-char *
-__osip_sdp_append_string (char *string, size_t size, char *cur, char *string_osip_to_append)
-{
-  size_t length = strlen (string_osip_to_append);
-
-  if (cur - string + length > size) {
-    size_t length2;
-
-    length2 = cur - string;
-    string = osip_realloc (string, size + length + 10);
-    cur = string + length2;     /* the initial allocation may have changed! */
-  }
-  osip_strncpy (cur, string_osip_to_append, length);
-  return cur + strlen (cur);
-}
+#if (_MSC_VER >= 1700) && !defined(_USING_V110_SDK71_)
+#if defined(WINAPI_FAMILY) && (WINAPI_FAMILY == WINAPI_FAMILY_PHONE_APP)
+#define HAVE_WINDOWSPHONE_API
+#elif defined(WINAPI_FAMILY) && WINAPI_FAMILY_ONE_PARTITION( WINAPI_FAMILY, WINAPI_PARTITION_APP )
+#define HAVE_WINAPPSTORE_API
+#endif
+#endif
 
 void
 osip_usleep (int useconds)
@@ -400,6 +400,22 @@ osip_usleep (int useconds)
   while (stoptime > TimGetTicks ())
     /* I wish there was some type of yield function here */
     ;
+#elif defined(HAVE_WINDOWSPHONE_API)
+  struct timeval delay;
+  int sec;
+
+  sec = (int) useconds / 1000000;
+  if (sec > 0) {
+    delay.tv_sec = sec;
+    delay.tv_usec = 0;
+  }
+  else {
+    delay.tv_sec = 0;
+    delay.tv_usec = useconds;
+  }
+  select (0, 0, 0, 0, &delay);
+#elif defined(HAVE_WINAPPSTORE_API)
+  TODO
 #elif defined(WIN32)
   Sleep (useconds / 1000);
 #elif defined(__rtems__)
@@ -771,9 +787,10 @@ osip_trace_initialize_syslog (osip_trace_level_t level, char *ident)
 {
 }
 
-void
+int
 osip_trace_initialize (osip_trace_level_t level, FILE * file)
 {
+  return OSIP_UNDEFINED_ERROR;
 }
 
 void
@@ -796,7 +813,7 @@ osip_is_trace_level_activate (osip_trace_level_t level)
 
 /* initialize log */
 /* all lower levels of level are logged in file. */
-void
+int
 osip_trace_initialize (osip_trace_level_t level, FILE * file)
 {
   osip_trace_level_t i = TRACE_LEVEL0;
@@ -818,6 +835,7 @@ osip_trace_initialize (osip_trace_level_t level, FILE * file)
       tracing_table[i] = LOG_FALSE;
     i++;
   }
+  return 0;
 }
 
 void
@@ -917,8 +935,12 @@ __osip_port_gettimeofday (struct timeval *tp, void *tz)
 #endif
 
 #ifndef MAX_LENGTH_TR
+#ifdef SYSTEM_LOGGER_ENABLED
+#define MAX_LENGTH_TR 2024      /* NEVER DEFINE MORE THAN 2024 */
+#else
 #define MAX_LENGTH_TR 512       /* NEVER DEFINE MORE THAN 2024 */
 #endif
+#endif
 
 int
 osip_trace (char *filename_long, int li, osip_trace_level_t level, FILE * f, char *chfr, ...)
@@ -1137,8 +1159,11 @@ osip_trace (char *filename_long, int li, osip_trace_level_t level, FILE * f, cha
 #ifdef UNICODE
     {
       WCHAR wUnicode[MAX_LENGTH_TR * 2];
+      int size;
 
-      MultiByteToWideChar (CP_UTF8, 0, buffer, -1, wUnicode, MAX_LENGTH_TR * 2);
+      size = MultiByteToWideChar (CP_UTF8, 0, buffer, -1, wUnicode, MAX_LENGTH_TR * 2);
+      wUnicode[size - 2] = '\n';
+      wUnicode[size - 1] = '\0';
       OutputDebugString (wUnicode);
     }
 #else
